@@ -1,5 +1,5 @@
 package Syntax::Infix::Smartmatch;
-$Syntax::Infix::Smartmatch::VERSION = '0.003';
+$Syntax::Infix::Smartmatch::VERSION = '0.004';
 use strict;
 use warnings;
 
@@ -36,7 +36,7 @@ Syntax::Infix::Smartmatch - Smartmatch done right
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -68,11 +68,7 @@ It will return the value of C<< $right->($left) >>
 
 =item * array
 
-This will compare every element of C<@$left> to see if it smartmatches every element of C<@$right>. E.g. C<< $left->[0] ~~ $right->[0] && $left->[1] ~~ $right->[1] && ... >>
-
-=item * bool
-
-This will always return C<$right>. This particularly is useful in second order constructs such as L<Syntax::Keyword::Match> (e.g. C<< case($topic > 1) >>. Bools are only available on perl v5.36 and up.
+This will return true if C<$left> smartmatches any of the members of C<@$right>.
 
 =item * other
 
